pitchtools.symbolic_accidental_string_to_alphabetic_accidental_abbreviation
===========================================================================

.. autofunction:: abjad.tools.pitchtools.symbolic_accidental_string_to_alphabetic_accidental_abbreviation.symbolic_accidental_string_to_alphabetic_accidental_abbreviation
